summaryrefslogtreecommitdiffstats
path: root/urpm/orphans.pm
diff options
context:
space:
mode:
Diffstat (limited to 'urpm/orphans.pm')
-rw-r--r--urpm/orphans.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/urpm/orphans.pm b/urpm/orphans.pm
index 5279eb1f..5068cd1d 100644
--- a/urpm/orphans.pm
+++ b/urpm/orphans.pm
@@ -139,7 +139,7 @@ sub _installed_req_and_unreq_and_update_unrequested_list {
}
#- returns the new "unrequested" packages
#- the reason can be "required by xxx" or "suggested"
#-
#- side-effects: none
sub _selected_unrequested {
@@ -153,7 +153,7 @@ sub _selected_unrequested {
$pkg->flag_requested || urpm::select::was_pkg_name_installed($rejected, $name) ? () :
($name => "(required by " . $from->fullname . ")");
} elsif ($selected->{$_}{recommended}) {
- ($urpm->{depslist}[$_]->name => "(suggested)");
+ ($urpm->{depslist}[$_]->name => "(recommended)");
} else {
();
}
@@ -139,7 +139,7 @@ sub _installed_req_and_unreq_and_update_unrequested_list {
}
#- returns the new "unrequested" packages
-#- the reason can be "required by xxx" or "suggested"
+#- the reason can be "required by xxx" or "recommended"
#-
#- side-effects: none